import os
import re
import webbrowser
from datetime import datetime
import pandas as pd
import numpy as np
import requests


class GameInfo:
	def __init__(self, url, lastplayed, tags, note):
		self.url = url
		self.name = ''
		self.version = ''
		self.date = None
		self.lastplayed = lastplayed
		self.tags = tags
		self.note = note

	def get_info(self):
		text = requests.get(self.url)
		headline_found = updated_found = False
		for item in text.text.split("\n"):
			if "headline" in item:
				headline_found = True
				headline = item.strip().replace('"headline": "', '').replace('",', '')
				self.name = headline.split(" [", -1)[0]
				self.version = headline.split(" [", -1)[1].split("]", -1)[0]
			if "Updated:" in item:
				updated_found = True
				try:
					date = re.search(r"(?<=Updated:)*?\d{4}-\d{2}-\d{2}", item.strip()).group(0)
				except AttributeError:
					try:
						date = re.search(r"(?<=Updated:)*?\d{4}-\d{1}-\d{2}", item.strip()).group(0)
					except AttributeError:
						try:
							date = re.search(r"(?<=Updated:)*?\d{4}-\d{2}-\d{1}", item.strip()).group(0)
						except AttributeError:
							date = re.search(r"(?<=Updated:)*?\d{4}-\d{1}-\d{1}", item.strip()).group(0)
				self.date = datetime.strptime(date, '%Y-%m-%d').date()
			if headline_found and updated_found:
				break

	def __lt__(self, other):
		return self.date > other.date

def checkVersion(versions, game, version):
	if game not in versions:
		versions[game] = version
		return False
	is_new = version != versions[game]
	versions[game] = version
	return is_new

# # # # # # # # # # #
# Creating a HTML file
# # # # # # # # # # #

try:
	df = pd.read_csv('links.csv', sep=';')
except FileNotFoundError:
	df = pd.read_excel('links.xlsx', sheet_name='List1')

games = []
for url, versionplayed, tags, note in zip(df['URL'], df['Version'], df['Tags'], df['Note']):
	if pd.isnull(note):
		note = ""
	if pd.isnull(versionplayed):
		versionplayed = ""
	games.append(GameInfo(url, versionplayed, tags, note))

max_length = 0

for game in games:
	game.get_info()
	if len(game.name) > max_length:
		max_length = len(game.name)

#games.sort()

html_str_begin = """
<!DOCTYPE html>

<html>
<head>
<title>F95Watcher</title>

<style>
body {
	background-color: #181A1D;
}

h2 {
	font-family: arial, sans-serif;
	color: #ffffff;
}

a:link, a:visited {
	color: #D05548;
}

table {
	font-family: arial, sans-serif;
	color: #ffffff;
	border-collapse: collapse;
}

td, th {
	border: 1px solid #dddddd;
	text-align: left;
	padding: 8px;
}

tr:nth-child(even) {
	background-color: #181A1D;
}

tr:nth-child(odd) {
	background-color: #242629;
}

table td:last-child{
	width:200px;
}

</style>

</head>
<body>

<h2>F95Watcher - Favorite games updates</h2>

<table>
	<tr>
		<th>Name</th>
		<th>Tags</th>
		<th>Played</th>
		<th>Latest Version</th>
		<th>Updated</th>
		<th>Note</th>
	</tr>
"""

try:
	versions = np.load('versions.npy', allow_pickle=True).item()
except IOError:
	versions = {}

html_file = open("Summary.html", "w")
html_file.write(html_str_begin)

for game in games:
	new = checkVersion(versions, game.name, game.version)
	notplayed = game.lastplayed and (game.version != game.lastplayed)
	html_file.write(
		("""\t<tr><td style="background-color: #006600;color: white;">""" if new else """\t<tr><td>""") + """<a target="_blank" rel="noopener noreferrer" href=\"""" + game.url + """\">""" + game.name + """</td><td>""" + (str(game.tags) if str(game.tags) != "nan" else """&nbsp;""") + """</td><td>""" + str(game.lastplayed) + """</td>""" + ("""<td style="background-color: #006600">""" if notplayed else """<td>""") + game.version + """</td><td>""" + game.date.strftime('%Y-%m-%d') + """</td><td>""" + str(game.note) + """</td></tr>\n""")

np.save('versions.npy', versions)

html_str_end = """</table>
</body>
</html>
"""
html_file.write(html_str_end)
html_file.close()

webbrowser.get('windows-default').open('file://' + os.path.realpath('Summary.html'))
